@@ -14,7 +14,7 @@ Usage::
 """
 from typing import Any, Dict, List, Type
 
-from botocore.client import ClientMeta
+from botocore.client import BaseClient, ClientMeta
 
 from .literals import (
     DataSourceSyncJobStatusType,
@@ -42,6 +42,7 @@ from .type_defs import (
     DescribeDataSourceResponseTypeDef,
     DescribeFaqResponseTypeDef,
     DescribeIndexResponseTypeDef,
+    DescribePrincipalMappingResponseTypeDef,
     DescribeQuerySuggestionsBlockListResponseTypeDef,
     DescribeQuerySuggestionsConfigResponseTypeDef,
     DescribeThesaurusResponseTypeDef,
@@ -51,9 +52,11 @@ from .type_defs import (
     DocumentTypeDef,
     FacetTypeDef,
     GetQuerySuggestionsResponseTypeDef,
+    GroupMembersTypeDef,
     ListDataSourcesResponseTypeDef,
     ListDataSourceSyncJobsResponseTypeDef,
     ListFaqsResponseTypeDef,
+    ListGroupsOlderThanOrderingIdResponseTypeDef,
     ListIndicesResponseTypeDef,
     ListQuerySuggestionsBlockListsResponseTypeDef,
     ListTagsForResourceResponseTypeDef,
@@ -95,52 +98,70 @@ class Exceptions:
     ValidationException: Type[BotocoreClientError]
 
 
-class kendraClient:
+class kendraClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/kendra.html#kendra.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html)
     """
 
     meta: ClientMeta
-    exceptions: Exceptions
+
+    @property
+    def exceptions(self) -> Exceptions:
+        """
+        kendraClient exceptions.
+        """
 
     def batch_delete_document(
         self,
         *,
         IndexId: str,
         DocumentIdList: List[str],
-        DataSourceSyncJobMetricTarget: DataSourceSyncJobMetricTargetTypeDef = None
+        DataSourceSyncJobMetricTarget: "DataSourceSyncJobMetricTargetTypeDef" = None
     ) -> BatchDeleteDocumentResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/kendra.html#kendra.Client.batch_delete_document)
+        Removes one or more documents from an index.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.batch_delete_document)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#batch_delete_document)
         """
 
     def batch_get_document_status(
-        self, *, IndexId: str, DocumentInfoList: List[DocumentInfoTypeDef]
+        self, *, IndexId: str, DocumentInfoList: List["DocumentInfoTypeDef"]
     ) -> BatchGetDocumentStatusResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/kendra.html#kendra.Client.batch_get_document_status)
+        Returns the indexing status for one or more documents submitted with the
+        `BatchPutDocument
+        <https://docs.aws.amazon.com/kendra/latest/dg/API_BatchPutDocument.html>`__
+        operation.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.batch_get_document_status)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#batch_get_document_status)
         """
 
     def batch_put_document(
-        self, *, IndexId: str, Documents: List[DocumentTypeDef], RoleArn: str = None
+        self, *, IndexId: str, Documents: List["DocumentTypeDef"], RoleArn: str = None
     ) -> BatchPutDocumentResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/kendra.html#kendra.Client.batch_put_document)
+        Adds one or more documents to an index.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.batch_put_document)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#batch_put_document)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/kendra.html#kendra.Client.can_paginate)
+        Check if an operation can be paginated.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#can_paginate)
         """
 
     def clear_query_suggestions(self, *, IndexId: str) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/kendra.html#kendra.Client.clear_query_suggestions)
+        Clears existing query suggestions from an index.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.clear_query_suggestions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#clear_query_suggestions)
         """
 
@@ -158,7 +179,9 @@ class kendraClient:
         ClientToken: str = None
     ) -> CreateDataSourceResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/kendra.html#kendra.Client.create_data_source)
+        Creates a data source that you use to with an Amazon Kendra index.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.create_data_source)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#create_data_source)
         """
 
@@ -175,7 +198,9 @@ class kendraClient:
         ClientToken: str = None
     ) -> CreateFaqResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/kendra.html#kendra.Client.create_faq)
+        Creates an new set of frequently asked question (FAQ) questions and answers.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.create_faq)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#create_faq)
         """
 
@@ -193,7 +218,9 @@ class kendraClient:
         UserContextPolicy: UserContextPolicyType = None
     ) -> CreateIndexResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/kendra.html#kendra.Client.create_index)
+        Creates a new Amazon Kendra index.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.create_index)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#create_index)
         """
 
@@ -209,7 +236,9 @@ class kendraClient:
         Tags: List["TagTypeDef"] = None
     ) -> CreateQuerySuggestionsBlockListResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/kendra.html#kendra.Client.create_query_suggestions_block_list)
+        Creates a block list to exlcude certain queries from suggestions.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.create_query_suggestions_block_list)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#create_query_suggestions_block_list)
         """
 
@@ -225,63 +254,107 @@ class kendraClient:
         ClientToken: str = None
     ) -> CreateThesaurusResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/kendra.html#kendra.Client.create_thesaurus)
+        Creates a thesaurus for an index.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.create_thesaurus)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#create_thesaurus)
         """
 
     def delete_data_source(self, *, Id: str, IndexId: str) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/kendra.html#kendra.Client.delete_data_source)
+        Deletes an Amazon Kendra data source.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.delete_data_source)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#delete_data_source)
         """
 
     def delete_faq(self, *, Id: str, IndexId: str) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/kendra.html#kendra.Client.delete_faq)
+        Removes an FAQ from an index.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.delete_faq)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#delete_faq)
         """
 
     def delete_index(self, *, Id: str) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/kendra.html#kendra.Client.delete_index)
+        Deletes an existing Amazon Kendra index.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.delete_index)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#delete_index)
         """
 
+    def delete_principal_mapping(
+        self, *, IndexId: str, GroupId: str, DataSourceId: str = None, OrderingId: int = None
+    ) -> None:
+        """
+        Deletes a group so that all users and sub groups that belong to the group can no
+        longer access documents only available to that group.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.delete_principal_mapping)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#delete_principal_mapping)
+        """
+
     def delete_query_suggestions_block_list(self, *, IndexId: str, Id: str) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/kendra.html#kendra.Client.delete_query_suggestions_block_list)
+        Deletes a block list used for query suggestions for an index.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.delete_query_suggestions_block_list)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#delete_query_suggestions_block_list)
         """
 
     def delete_thesaurus(self, *, Id: str, IndexId: str) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/kendra.html#kendra.Client.delete_thesaurus)
+        Deletes an existing Amazon Kendra thesaurus.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.delete_thesaurus)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#delete_thesaurus)
         """
 
     def describe_data_source(self, *, Id: str, IndexId: str) -> DescribeDataSourceResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/kendra.html#kendra.Client.describe_data_source)
+        Gets information about a Amazon Kendra data source.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.describe_data_source)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#describe_data_source)
         """
 
     def describe_faq(self, *, Id: str, IndexId: str) -> DescribeFaqResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/kendra.html#kendra.Client.describe_faq)
+        Gets information about an FAQ list.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.describe_faq)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#describe_faq)
         """
 
     def describe_index(self, *, Id: str) -> DescribeIndexResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/kendra.html#kendra.Client.describe_index)
+        Describes an existing Amazon Kendra index See also: `AWS API Documentation
+        <https://docs.aws.amazon.com/goto/WebAPI/kendra-2019-02-03/DescribeIndex>`_
+        **Request Syntax** response = client.describe_index( Id='string' ).
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.describe_index)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#describe_index)
         """
 
+    def describe_principal_mapping(
+        self, *, IndexId: str, GroupId: str, DataSourceId: str = None
+    ) -> DescribePrincipalMappingResponseTypeDef:
+        """
+        Describes the processing of `PUT` and `DELETE` actions for mapping users to
+        their groups.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.describe_principal_mapping)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#describe_principal_mapping)
+        """
+
     def describe_query_suggestions_block_list(
         self, *, IndexId: str, Id: str
     ) -> DescribeQuerySuggestionsBlockListResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/kendra.html#kendra.Client.describe_query_suggestions_block_list)
+        Describes a block list used for query suggestions for an index.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.describe_query_suggestions_block_list)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#describe_query_suggestions_block_list)
         """
 
@@ -289,13 +362,17 @@ class kendraClient:
         self, *, IndexId: str
     ) -> DescribeQuerySuggestionsConfigResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/kendra.html#kendra.Client.describe_query_suggestions_config)
+        Describes the settings of query suggestions for an index.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.describe_query_suggestions_config)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#describe_query_suggestions_config)
         """
 
     def describe_thesaurus(self, *, Id: str, IndexId: str) -> DescribeThesaurusResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/kendra.html#kendra.Client.describe_thesaurus)
+        Describes an existing Amazon Kendra thesaurus.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.describe_thesaurus)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#describe_thesaurus)
         """
 
@@ -307,7 +384,9 @@ class kendraClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/kendra.html#kendra.Client.generate_presigned_url)
+        Generate a presigned url given a client, its method, and arguments.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#generate_presigned_url)
         """
 
@@ -315,7 +394,9 @@ class kendraClient:
         self, *, IndexId: str, QueryText: str, MaxSuggestionsCount: int = None
     ) -> GetQuerySuggestionsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/kendra.html#kendra.Client.get_query_suggestions)
+        Fetches the queries that are suggested to your users.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.get_query_suggestions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#get_query_suggestions)
         """
 
@@ -326,11 +407,13 @@ class kendraClient:
         IndexId: str,
         NextToken: str = None,
         MaxResults: int = None,
-        StartTimeFilter: TimeRangeTypeDef = None,
+        StartTimeFilter: "TimeRangeTypeDef" = None,
         StatusFilter: DataSourceSyncJobStatusType = None
     ) -> ListDataSourceSyncJobsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/kendra.html#kendra.Client.list_data_source_sync_jobs)
+        Gets statistics about synchronizing Amazon Kendra with a data source.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.list_data_source_sync_jobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#list_data_source_sync_jobs)
         """
 
@@ -338,7 +421,9 @@ class kendraClient:
         self, *, IndexId: str, NextToken: str = None, MaxResults: int = None
     ) -> ListDataSourcesResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/kendra.html#kendra.Client.list_data_sources)
+        Lists the data sources that you have created.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.list_data_sources)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#list_data_sources)
         """
 
@@ -346,15 +431,36 @@ class kendraClient:
         self, *, IndexId: str, NextToken: str = None, MaxResults: int = None
     ) -> ListFaqsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/kendra.html#kendra.Client.list_faqs)
+        Gets a list of FAQ lists associated with an index.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.list_faqs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#list_faqs)
         """
 
+    def list_groups_older_than_ordering_id(
+        self,
+        *,
+        IndexId: str,
+        OrderingId: int,
+        DataSourceId: str = None,
+        NextToken: str = None,
+        MaxResults: int = None
+    ) -> ListGroupsOlderThanOrderingIdResponseTypeDef:
+        """
+        Provides a list of groups that are mapped to users before a given ordering or
+        timestamp identifier.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.list_groups_older_than_ordering_id)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#list_groups_older_than_ordering_id)
+        """
+
     def list_indices(
         self, *, NextToken: str = None, MaxResults: int = None
     ) -> ListIndicesResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/kendra.html#kendra.Client.list_indices)
+        Lists the Amazon Kendra indexes that you have created.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.list_indices)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#list_indices)
         """
 
@@ -362,13 +468,17 @@ class kendraClient:
         self, *, IndexId: str, NextToken: str = None, MaxResults: int = None
     ) -> ListQuerySuggestionsBlockListsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/kendra.html#kendra.Client.list_query_suggestions_block_lists)
+        Lists the block lists used for query suggestions for an index.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.list_query_suggestions_block_lists)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#list_query_suggestions_block_lists)
         """
 
     def list_tags_for_resource(self, *, ResourceARN: str) -> ListTagsForResourceResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/kendra.html#kendra.Client.list_tags_for_resource)
+        Gets a list of tags associated with a specified resource.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#list_tags_for_resource)
         """
 
@@ -376,28 +486,51 @@ class kendraClient:
         self, *, IndexId: str, NextToken: str = None, MaxResults: int = None
     ) -> ListThesauriResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/kendra.html#kendra.Client.list_thesauri)
+        Lists the Amazon Kendra thesauri associated with an index.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.list_thesauri)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#list_thesauri)
         """
 
+    def put_principal_mapping(
+        self,
+        *,
+        IndexId: str,
+        GroupId: str,
+        GroupMembers: "GroupMembersTypeDef",
+        DataSourceId: str = None,
+        OrderingId: int = None,
+        RoleArn: str = None
+    ) -> None:
+        """
+        Maps users to their groups.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.put_principal_mapping)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#put_principal_mapping)
+        """
+
     def query(
         self,
         *,
         IndexId: str,
         QueryText: str,
         AttributeFilter: "AttributeFilterTypeDef" = None,
-        Facets: List[FacetTypeDef] = None,
+        Facets: List["FacetTypeDef"] = None,
         RequestedDocumentAttributes: List[str] = None,
         QueryResultTypeFilter: QueryResultTypeType = None,
-        DocumentRelevanceOverrideConfigurations: List[DocumentRelevanceConfigurationTypeDef] = None,
+        DocumentRelevanceOverrideConfigurations: List[
+            "DocumentRelevanceConfigurationTypeDef"
+        ] = None,
         PageNumber: int = None,
         PageSize: int = None,
-        SortingConfiguration: SortingConfigurationTypeDef = None,
-        UserContext: UserContextTypeDef = None,
+        SortingConfiguration: "SortingConfigurationTypeDef" = None,
+        UserContext: "UserContextTypeDef" = None,
         VisitorId: str = None
     ) -> QueryResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/kendra.html#kendra.Client.query)
+        Searches an active index.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.query)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#query)
         """
 
@@ -405,13 +538,17 @@ class kendraClient:
         self, *, Id: str, IndexId: str
     ) -> StartDataSourceSyncJobResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/kendra.html#kendra.Client.start_data_source_sync_job)
+        Starts a synchronization job for a data source.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.start_data_source_sync_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#start_data_source_sync_job)
         """
 
     def stop_data_source_sync_job(self, *, Id: str, IndexId: str) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/kendra.html#kendra.Client.stop_data_source_sync_job)
+        Stops a running synchronization job.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.stop_data_source_sync_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#stop_data_source_sync_job)
         """
 
@@ -420,23 +557,30 @@ class kendraClient:
         *,
         IndexId: str,
         QueryId: str,
-        ClickFeedbackItems: List[ClickFeedbackTypeDef] = None,
-        RelevanceFeedbackItems: List[RelevanceFeedbackTypeDef] = None
+        ClickFeedbackItems: List["ClickFeedbackTypeDef"] = None,
+        RelevanceFeedbackItems: List["RelevanceFeedbackTypeDef"] = None
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/kendra.html#kendra.Client.submit_feedback)
+        Enables you to provide feedback to Amazon Kendra to improve the performance of
+        your index.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.submit_feedback)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#submit_feedback)
         """
 
     def tag_resource(self, *, ResourceARN: str, Tags: List["TagTypeDef"]) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/kendra.html#kendra.Client.tag_resource)
+        Adds the specified tag to the specified index, FAQ, or data source resource.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#tag_resource)
         """
 
     def untag_resource(self, *, ResourceARN: str, TagKeys: List[str]) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/kendra.html#kendra.Client.untag_resource)
+        Removes a tag from an index, FAQ, or a data source.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#untag_resource)
         """
 
@@ -452,7 +596,9 @@ class kendraClient:
         RoleArn: str = None
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/kendra.html#kendra.Client.update_data_source)
+        Updates an existing Amazon Kendra data source.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.update_data_source)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#update_data_source)
         """
 
@@ -469,7 +615,9 @@ class kendraClient:
         UserContextPolicy: UserContextPolicyType = None
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/kendra.html#kendra.Client.update_index)
+        Updates an existing Amazon Kendra index.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.update_index)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#update_index)
         """
 
@@ -484,7 +632,9 @@ class kendraClient:
         RoleArn: str = None
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/kendra.html#kendra.Client.update_query_suggestions_block_list)
+        Updates a block list used for query suggestions for an index.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.update_query_suggestions_block_list)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#update_query_suggestions_block_list)
         """
 
@@ -499,7 +649,9 @@ class kendraClient:
         MinimumQueryCount: int = None
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/kendra.html#kendra.Client.update_query_suggestions_config)
+        Updates the settings of query suggestions for an index.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.update_query_suggestions_config)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#update_query_suggestions_config)
         """
 
@@ -514,6 +666,8 @@ class kendraClient:
         SourceS3Path: "S3PathTypeDef" = None
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/kendra.html#kendra.Client.update_thesaurus)
+        Updates a thesaurus file associated with an index.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.28/reference/services/kendra.html#kendra.Client.update_thesaurus)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kendra/client.html#update_thesaurus)
         """
