@@ -39,6 +39,7 @@ from .literals import (
     KeyLocationType,
     ModeType,
     OrderType,
+    PrincipalMappingStatusType,
     PrincipalTypeType,
     QueryIdentifiersEnclosingOptionType,
     QueryResultTypeType,
@@ -77,13 +78,17 @@ __all__ = (
     "AttributeFilterTypeDef",
     "AuthenticationConfigurationTypeDef",
     "BasicAuthenticationConfigurationTypeDef",
+    "BatchDeleteDocumentRequestRequestTypeDef",
     "BatchDeleteDocumentResponseFailedDocumentTypeDef",
     "BatchDeleteDocumentResponseTypeDef",
+    "BatchGetDocumentStatusRequestRequestTypeDef",
     "BatchGetDocumentStatusResponseErrorTypeDef",
     "BatchGetDocumentStatusResponseTypeDef",
+    "BatchPutDocumentRequestRequestTypeDef",
     "BatchPutDocumentResponseFailedDocumentTypeDef",
     "BatchPutDocumentResponseTypeDef",
     "CapacityUnitsConfigurationTypeDef",
+    "ClearQuerySuggestionsRequestRequestTypeDef",
     "ClickFeedbackTypeDef",
     "ColumnConfigurationTypeDef",
     "ConfluenceAttachmentConfigurationTypeDef",
@@ -96,12 +101,18 @@ __all__ = (
     "ConfluenceSpaceConfigurationTypeDef",
     "ConfluenceSpaceToIndexFieldMappingTypeDef",
     "ConnectionConfigurationTypeDef",
+    "CreateDataSourceRequestRequestTypeDef",
     "CreateDataSourceResponseTypeDef",
+    "CreateFaqRequestRequestTypeDef",
     "CreateFaqResponseTypeDef",
+    "CreateIndexRequestRequestTypeDef",
     "CreateIndexResponseTypeDef",
+    "CreateQuerySuggestionsBlockListRequestRequestTypeDef",
     "CreateQuerySuggestionsBlockListResponseTypeDef",
+    "CreateThesaurusRequestRequestTypeDef",
     "CreateThesaurusResponseTypeDef",
     "DataSourceConfigurationTypeDef",
+    "DataSourceGroupTypeDef",
     "DataSourceSummaryTypeDef",
     "DataSourceSyncJobMetricTargetTypeDef",
     "DataSourceSyncJobMetricsTypeDef",
@@ -109,11 +120,25 @@ __all__ = (
     "DataSourceToIndexFieldMappingTypeDef",
     "DataSourceVpcConfigurationTypeDef",
     "DatabaseConfigurationTypeDef",
+    "DeleteDataSourceRequestRequestTypeDef",
+    "DeleteFaqRequestRequestTypeDef",
+    "DeleteIndexRequestRequestTypeDef",
+    "DeletePrincipalMappingRequestRequestTypeDef",
+    "DeleteQuerySuggestionsBlockListRequestRequestTypeDef",
+    "DeleteThesaurusRequestRequestTypeDef",
+    "DescribeDataSourceRequestRequestTypeDef",
     "DescribeDataSourceResponseTypeDef",
+    "DescribeFaqRequestRequestTypeDef",
     "DescribeFaqResponseTypeDef",
+    "DescribeIndexRequestRequestTypeDef",
     "DescribeIndexResponseTypeDef",
+    "DescribePrincipalMappingRequestRequestTypeDef",
+    "DescribePrincipalMappingResponseTypeDef",
+    "DescribeQuerySuggestionsBlockListRequestRequestTypeDef",
     "DescribeQuerySuggestionsBlockListResponseTypeDef",
+    "DescribeQuerySuggestionsConfigRequestRequestTypeDef",
     "DescribeQuerySuggestionsConfigResponseTypeDef",
+    "DescribeThesaurusRequestRequestTypeDef",
     "DescribeThesaurusResponseTypeDef",
     "DocumentAttributeTypeDef",
     "DocumentAttributeValueCountPairTypeDef",
@@ -127,29 +152,48 @@ __all__ = (
     "FacetTypeDef",
     "FaqStatisticsTypeDef",
     "FaqSummaryTypeDef",
+    "GetQuerySuggestionsRequestRequestTypeDef",
     "GetQuerySuggestionsResponseTypeDef",
     "GoogleDriveConfigurationTypeDef",
+    "GroupMembersTypeDef",
+    "GroupOrderingIdSummaryTypeDef",
+    "GroupSummaryTypeDef",
+    "HierarchicalPrincipalTypeDef",
     "HighlightTypeDef",
     "IndexConfigurationSummaryTypeDef",
     "IndexStatisticsTypeDef",
     "JsonTokenTypeConfigurationTypeDef",
     "JwtTokenTypeConfigurationTypeDef",
+    "ListDataSourceSyncJobsRequestRequestTypeDef",
     "ListDataSourceSyncJobsResponseTypeDef",
+    "ListDataSourcesRequestRequestTypeDef",
     "ListDataSourcesResponseTypeDef",
+    "ListFaqsRequestRequestTypeDef",
     "ListFaqsResponseTypeDef",
+    "ListGroupsOlderThanOrderingIdRequestRequestTypeDef",
+    "ListGroupsOlderThanOrderingIdResponseTypeDef",
+    "ListIndicesRequestRequestTypeDef",
     "ListIndicesResponseTypeDef",
+    "ListQuerySuggestionsBlockListsRequestRequestTypeDef",
     "ListQuerySuggestionsBlockListsResponseTypeDef",
+    "ListTagsForResourceRequestRequestTypeDef",
     "ListTagsForResourceResponseTypeDef",
+    "ListThesauriRequestRequestTypeDef",
     "ListThesauriResponseTypeDef",
+    "MemberGroupTypeDef",
+    "MemberUserTypeDef",
     "OneDriveConfigurationTypeDef",
     "OneDriveUsersTypeDef",
     "PrincipalTypeDef",
     "ProxyConfigurationTypeDef",
+    "PutPrincipalMappingRequestRequestTypeDef",
+    "QueryRequestRequestTypeDef",
     "QueryResultItemTypeDef",
     "QueryResultTypeDef",
     "QuerySuggestionsBlockListSummaryTypeDef",
     "RelevanceFeedbackTypeDef",
     "RelevanceTypeDef",
+    "ResponseMetadataTypeDef",
     "S3DataSourceConfigurationTypeDef",
     "S3PathTypeDef",
     "SalesforceChatterFeedConfigurationTypeDef",
@@ -170,21 +214,32 @@ __all__ = (
     "SiteMapsConfigurationTypeDef",
     "SortingConfigurationTypeDef",
     "SqlConfigurationTypeDef",
+    "StartDataSourceSyncJobRequestRequestTypeDef",
     "StartDataSourceSyncJobResponseTypeDef",
     "StatusTypeDef",
+    "StopDataSourceSyncJobRequestRequestTypeDef",
+    "SubmitFeedbackRequestRequestTypeDef",
     "SuggestionHighlightTypeDef",
     "SuggestionTextWithHighlightsTypeDef",
     "SuggestionTypeDef",
     "SuggestionValueTypeDef",
+    "TagResourceRequestRequestTypeDef",
     "TagTypeDef",
     "TextDocumentStatisticsTypeDef",
     "TextWithHighlightsTypeDef",
     "ThesaurusSummaryTypeDef",
     "TimeRangeTypeDef",
+    "UntagResourceRequestRequestTypeDef",
+    "UpdateDataSourceRequestRequestTypeDef",
+    "UpdateIndexRequestRequestTypeDef",
+    "UpdateQuerySuggestionsBlockListRequestRequestTypeDef",
+    "UpdateQuerySuggestionsConfigRequestRequestTypeDef",
+    "UpdateThesaurusRequestRequestTypeDef",
     "UrlsTypeDef",
     "UserContextTypeDef",
     "UserTokenConfigurationTypeDef",
     "WebCrawlerConfigurationTypeDef",
+    "WorkDocsConfigurationTypeDef",
 )
 
 AccessControlListConfigurationTypeDef = TypedDict(
@@ -253,6 +308,29 @@ BasicAuthenticationConfigurationTypeDef = TypedDict(
     },
 )
 
+_RequiredBatchDeleteDocumentRequestRequestTypeDef = TypedDict(
+    "_RequiredBatchDeleteDocumentRequestRequestTypeDef",
+    {
+        "IndexId": str,
+        "DocumentIdList": List[str],
+    },
+)
+_OptionalBatchDeleteDocumentRequestRequestTypeDef = TypedDict(
+    "_OptionalBatchDeleteDocumentRequestRequestTypeDef",
+    {
+        "DataSourceSyncJobMetricTarget": "DataSourceSyncJobMetricTargetTypeDef",
+    },
+    total=False,
+)
+
+
+class BatchDeleteDocumentRequestRequestTypeDef(
+    _RequiredBatchDeleteDocumentRequestRequestTypeDef,
+    _OptionalBatchDeleteDocumentRequestRequestTypeDef,
+):
+    pass
+
+
 BatchDeleteDocumentResponseFailedDocumentTypeDef = TypedDict(
     "BatchDeleteDocumentResponseFailedDocumentTypeDef",
     {
@@ -267,8 +345,16 @@ BatchDeleteDocumentResponseTypeDef = TypedDict(
     "BatchDeleteDocumentResponseTypeDef",
     {
         "FailedDocuments": List["BatchDeleteDocumentResponseFailedDocumentTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+BatchGetDocumentStatusRequestRequestTypeDef = TypedDict(
+    "BatchGetDocumentStatusRequestRequestTypeDef",
+    {
+        "IndexId": str,
+        "DocumentInfoList": List["DocumentInfoTypeDef"],
     },
-    total=False,
 )
 
 BatchGetDocumentStatusResponseErrorTypeDef = TypedDict(
@@ -286,10 +372,32 @@ BatchGetDocumentStatusResponseTypeDef = TypedDict(
     {
         "Errors": List["BatchGetDocumentStatusResponseErrorTypeDef"],
         "DocumentStatusList": List["StatusTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredBatchPutDocumentRequestRequestTypeDef = TypedDict(
+    "_RequiredBatchPutDocumentRequestRequestTypeDef",
+    {
+        "IndexId": str,
+        "Documents": List["DocumentTypeDef"],
+    },
+)
+_OptionalBatchPutDocumentRequestRequestTypeDef = TypedDict(
+    "_OptionalBatchPutDocumentRequestRequestTypeDef",
+    {
+        "RoleArn": str,
     },
     total=False,
 )
 
+
+class BatchPutDocumentRequestRequestTypeDef(
+    _RequiredBatchPutDocumentRequestRequestTypeDef, _OptionalBatchPutDocumentRequestRequestTypeDef
+):
+    pass
+
+
 BatchPutDocumentResponseFailedDocumentTypeDef = TypedDict(
     "BatchPutDocumentResponseFailedDocumentTypeDef",
     {
@@ -304,8 +412,8 @@ BatchPutDocumentResponseTypeDef = TypedDict(
     "BatchPutDocumentResponseTypeDef",
     {
         "FailedDocuments": List["BatchPutDocumentResponseFailedDocumentTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 CapacityUnitsConfigurationTypeDef = TypedDict(
@@ -316,11 +424,18 @@ CapacityUnitsConfigurationTypeDef = TypedDict(
     },
 )
 
+ClearQuerySuggestionsRequestRequestTypeDef = TypedDict(
+    "ClearQuerySuggestionsRequestRequestTypeDef",
+    {
+        "IndexId": str,
+    },
+)
+
 ClickFeedbackTypeDef = TypedDict(
     "ClickFeedbackTypeDef",
     {
         "ResultId": str,
-        "ClickTime": datetime,
+        "ClickTime": Union[datetime, str],
     },
 )
 
@@ -465,43 +580,180 @@ ConnectionConfigurationTypeDef = TypedDict(
     },
 )
 
+_RequiredCreateDataSourceRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateDataSourceRequestRequestTypeDef",
+    {
+        "Name": str,
+        "IndexId": str,
+        "Type": DataSourceTypeType,
+    },
+)
+_OptionalCreateDataSourceRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateDataSourceRequestRequestTypeDef",
+    {
+        "Configuration": "DataSourceConfigurationTypeDef",
+        "Description": str,
+        "Schedule": str,
+        "RoleArn": str,
+        "Tags": List["TagTypeDef"],
+        "ClientToken": str,
+    },
+    total=False,
+)
+
+
+class CreateDataSourceRequestRequestTypeDef(
+    _RequiredCreateDataSourceRequestRequestTypeDef, _OptionalCreateDataSourceRequestRequestTypeDef
+):
+    pass
+
+
 CreateDataSourceResponseTypeDef = TypedDict(
     "CreateDataSourceResponseTypeDef",
     {
         "Id": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
+_RequiredCreateFaqRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateFaqRequestRequestTypeDef",
+    {
+        "IndexId": str,
+        "Name": str,
+        "S3Path": "S3PathTypeDef",
+        "RoleArn": str,
+    },
+)
+_OptionalCreateFaqRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateFaqRequestRequestTypeDef",
+    {
+        "Description": str,
+        "Tags": List["TagTypeDef"],
+        "FileFormat": FaqFileFormatType,
+        "ClientToken": str,
+    },
+    total=False,
+)
+
+
+class CreateFaqRequestRequestTypeDef(
+    _RequiredCreateFaqRequestRequestTypeDef, _OptionalCreateFaqRequestRequestTypeDef
+):
+    pass
+
+
 CreateFaqResponseTypeDef = TypedDict(
     "CreateFaqResponseTypeDef",
     {
         "Id": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredCreateIndexRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateIndexRequestRequestTypeDef",
+    {
+        "Name": str,
+        "RoleArn": str,
+    },
+)
+_OptionalCreateIndexRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateIndexRequestRequestTypeDef",
+    {
+        "Edition": IndexEditionType,
+        "ServerSideEncryptionConfiguration": "ServerSideEncryptionConfigurationTypeDef",
+        "Description": str,
+        "ClientToken": str,
+        "Tags": List["TagTypeDef"],
+        "UserTokenConfigurations": List["UserTokenConfigurationTypeDef"],
+        "UserContextPolicy": UserContextPolicyType,
     },
     total=False,
 )
 
+
+class CreateIndexRequestRequestTypeDef(
+    _RequiredCreateIndexRequestRequestTypeDef, _OptionalCreateIndexRequestRequestTypeDef
+):
+    pass
+
+
 CreateIndexResponseTypeDef = TypedDict(
     "CreateIndexResponseTypeDef",
     {
         "Id": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredCreateQuerySuggestionsBlockListRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateQuerySuggestionsBlockListRequestRequestTypeDef",
+    {
+        "IndexId": str,
+        "Name": str,
+        "SourceS3Path": "S3PathTypeDef",
+        "RoleArn": str,
+    },
+)
+_OptionalCreateQuerySuggestionsBlockListRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateQuerySuggestionsBlockListRequestRequestTypeDef",
+    {
+        "Description": str,
+        "ClientToken": str,
+        "Tags": List["TagTypeDef"],
     },
     total=False,
 )
 
+
+class CreateQuerySuggestionsBlockListRequestRequestTypeDef(
+    _RequiredCreateQuerySuggestionsBlockListRequestRequestTypeDef,
+    _OptionalCreateQuerySuggestionsBlockListRequestRequestTypeDef,
+):
+    pass
+
+
 CreateQuerySuggestionsBlockListResponseTypeDef = TypedDict(
     "CreateQuerySuggestionsBlockListResponseTypeDef",
     {
         "Id": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredCreateThesaurusRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateThesaurusRequestRequestTypeDef",
+    {
+        "IndexId": str,
+        "Name": str,
+        "RoleArn": str,
+        "SourceS3Path": "S3PathTypeDef",
+    },
+)
+_OptionalCreateThesaurusRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateThesaurusRequestRequestTypeDef",
+    {
+        "Description": str,
+        "Tags": List["TagTypeDef"],
+        "ClientToken": str,
     },
     total=False,
 )
 
+
+class CreateThesaurusRequestRequestTypeDef(
+    _RequiredCreateThesaurusRequestRequestTypeDef, _OptionalCreateThesaurusRequestRequestTypeDef
+):
+    pass
+
+
 CreateThesaurusResponseTypeDef = TypedDict(
     "CreateThesaurusResponseTypeDef",
     {
         "Id": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 DataSourceConfigurationTypeDef = TypedDict(
@@ -516,10 +768,19 @@ DataSourceConfigurationTypeDef = TypedDict(
         "ConfluenceConfiguration": "ConfluenceConfigurationTypeDef",
         "GoogleDriveConfiguration": "GoogleDriveConfigurationTypeDef",
         "WebCrawlerConfiguration": "WebCrawlerConfigurationTypeDef",
+        "WorkDocsConfiguration": "WorkDocsConfigurationTypeDef",
     },
     total=False,
 )
 
+DataSourceGroupTypeDef = TypedDict(
+    "DataSourceGroupTypeDef",
+    {
+        "GroupId": str,
+        "DataSourceId": str,
+    },
+)
+
 DataSourceSummaryTypeDef = TypedDict(
     "DataSourceSummaryTypeDef",
     {
@@ -636,6 +897,77 @@ class DatabaseConfigurationTypeDef(
     pass
 
 
+DeleteDataSourceRequestRequestTypeDef = TypedDict(
+    "DeleteDataSourceRequestRequestTypeDef",
+    {
+        "Id": str,
+        "IndexId": str,
+    },
+)
+
+DeleteFaqRequestRequestTypeDef = TypedDict(
+    "DeleteFaqRequestRequestTypeDef",
+    {
+        "Id": str,
+        "IndexId": str,
+    },
+)
+
+DeleteIndexRequestRequestTypeDef = TypedDict(
+    "DeleteIndexRequestRequestTypeDef",
+    {
+        "Id": str,
+    },
+)
+
+_RequiredDeletePrincipalMappingRequestRequestTypeDef = TypedDict(
+    "_RequiredDeletePrincipalMappingRequestRequestTypeDef",
+    {
+        "IndexId": str,
+        "GroupId": str,
+    },
+)
+_OptionalDeletePrincipalMappingRequestRequestTypeDef = TypedDict(
+    "_OptionalDeletePrincipalMappingRequestRequestTypeDef",
+    {
+        "DataSourceId": str,
+        "OrderingId": int,
+    },
+    total=False,
+)
+
+
+class DeletePrincipalMappingRequestRequestTypeDef(
+    _RequiredDeletePrincipalMappingRequestRequestTypeDef,
+    _OptionalDeletePrincipalMappingRequestRequestTypeDef,
+):
+    pass
+
+
+DeleteQuerySuggestionsBlockListRequestRequestTypeDef = TypedDict(
+    "DeleteQuerySuggestionsBlockListRequestRequestTypeDef",
+    {
+        "IndexId": str,
+        "Id": str,
+    },
+)
+
+DeleteThesaurusRequestRequestTypeDef = TypedDict(
+    "DeleteThesaurusRequestRequestTypeDef",
+    {
+        "Id": str,
+        "IndexId": str,
+    },
+)
+
+DescribeDataSourceRequestRequestTypeDef = TypedDict(
+    "DescribeDataSourceRequestRequestTypeDef",
+    {
+        "Id": str,
+        "IndexId": str,
+    },
+)
+
 DescribeDataSourceResponseTypeDef = TypedDict(
     "DescribeDataSourceResponseTypeDef",
     {
@@ -651,8 +983,16 @@ DescribeDataSourceResponseTypeDef = TypedDict(
         "Schedule": str,
         "RoleArn": str,
         "ErrorMessage": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+DescribeFaqRequestRequestTypeDef = TypedDict(
+    "DescribeFaqRequestRequestTypeDef",
+    {
+        "Id": str,
+        "IndexId": str,
     },
-    total=False,
 )
 
 DescribeFaqResponseTypeDef = TypedDict(
@@ -669,8 +1009,15 @@ DescribeFaqResponseTypeDef = TypedDict(
         "RoleArn": str,
         "ErrorMessage": str,
         "FileFormat": FaqFileFormatType,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+DescribeIndexRequestRequestTypeDef = TypedDict(
+    "DescribeIndexRequestRequestTypeDef",
+    {
+        "Id": str,
     },
-    total=False,
 )
 
 DescribeIndexResponseTypeDef = TypedDict(
@@ -691,10 +1038,52 @@ DescribeIndexResponseTypeDef = TypedDict(
         "CapacityUnits": "CapacityUnitsConfigurationTypeDef",
         "UserTokenConfigurations": List["UserTokenConfigurationTypeDef"],
         "UserContextPolicy": UserContextPolicyType,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredDescribePrincipalMappingRequestRequestTypeDef = TypedDict(
+    "_RequiredDescribePrincipalMappingRequestRequestTypeDef",
+    {
+        "IndexId": str,
+        "GroupId": str,
+    },
+)
+_OptionalDescribePrincipalMappingRequestRequestTypeDef = TypedDict(
+    "_OptionalDescribePrincipalMappingRequestRequestTypeDef",
+    {
+        "DataSourceId": str,
     },
     total=False,
 )
 
+
+class DescribePrincipalMappingRequestRequestTypeDef(
+    _RequiredDescribePrincipalMappingRequestRequestTypeDef,
+    _OptionalDescribePrincipalMappingRequestRequestTypeDef,
+):
+    pass
+
+
+DescribePrincipalMappingResponseTypeDef = TypedDict(
+    "DescribePrincipalMappingResponseTypeDef",
+    {
+        "IndexId": str,
+        "DataSourceId": str,
+        "GroupId": str,
+        "GroupOrderingIdSummaries": List["GroupOrderingIdSummaryTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+DescribeQuerySuggestionsBlockListRequestRequestTypeDef = TypedDict(
+    "DescribeQuerySuggestionsBlockListRequestRequestTypeDef",
+    {
+        "IndexId": str,
+        "Id": str,
+    },
+)
+
 DescribeQuerySuggestionsBlockListResponseTypeDef = TypedDict(
     "DescribeQuerySuggestionsBlockListResponseTypeDef",
     {
@@ -710,8 +1099,15 @@ DescribeQuerySuggestionsBlockListResponseTypeDef = TypedDict(
         "ItemCount": int,
         "FileSizeBytes": int,
         "RoleArn": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+DescribeQuerySuggestionsConfigRequestRequestTypeDef = TypedDict(
+    "DescribeQuerySuggestionsConfigRequestRequestTypeDef",
+    {
+        "IndexId": str,
     },
-    total=False,
 )
 
 DescribeQuerySuggestionsConfigResponseTypeDef = TypedDict(
@@ -726,8 +1122,16 @@ DescribeQuerySuggestionsConfigResponseTypeDef = TypedDict(
         "LastSuggestionsBuildTime": datetime,
         "LastClearTime": datetime,
         "TotalSuggestionsCount": int,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+DescribeThesaurusRequestRequestTypeDef = TypedDict(
+    "DescribeThesaurusRequestRequestTypeDef",
+    {
+        "Id": str,
+        "IndexId": str,
     },
-    total=False,
 )
 
 DescribeThesaurusResponseTypeDef = TypedDict(
@@ -746,8 +1150,8 @@ DescribeThesaurusResponseTypeDef = TypedDict(
         "FileSizeBytes": int,
         "TermCount": int,
         "SynonymRuleCount": int,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 DocumentAttributeTypeDef = TypedDict(
@@ -773,7 +1177,7 @@ DocumentAttributeValueTypeDef = TypedDict(
         "StringValue": str,
         "StringListValue": List[str],
         "LongValue": int,
-        "DateValue": datetime,
+        "DateValue": Union[datetime, str],
     },
     total=False,
 )
@@ -842,6 +1246,7 @@ _OptionalDocumentTypeDef = TypedDict(
         "S3Path": "S3PathTypeDef",
         "Attributes": List["DocumentAttributeTypeDef"],
         "AccessControlList": List["PrincipalTypeDef"],
+        "HierarchicalAccessControlList": List["HierarchicalPrincipalTypeDef"],
         "ContentType": ContentTypeType,
     },
     total=False,
@@ -898,13 +1303,36 @@ FaqSummaryTypeDef = TypedDict(
     total=False,
 )
 
+_RequiredGetQuerySuggestionsRequestRequestTypeDef = TypedDict(
+    "_RequiredGetQuerySuggestionsRequestRequestTypeDef",
+    {
+        "IndexId": str,
+        "QueryText": str,
+    },
+)
+_OptionalGetQuerySuggestionsRequestRequestTypeDef = TypedDict(
+    "_OptionalGetQuerySuggestionsRequestRequestTypeDef",
+    {
+        "MaxSuggestionsCount": int,
+    },
+    total=False,
+)
+
+
+class GetQuerySuggestionsRequestRequestTypeDef(
+    _RequiredGetQuerySuggestionsRequestRequestTypeDef,
+    _OptionalGetQuerySuggestionsRequestRequestTypeDef,
+):
+    pass
+
+
 GetQuerySuggestionsResponseTypeDef = TypedDict(
     "GetQuerySuggestionsResponseTypeDef",
     {
         "QuerySuggestionsId": str,
         "Suggestions": List["SuggestionTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 _RequiredGoogleDriveConfigurationTypeDef = TypedDict(
@@ -933,6 +1361,44 @@ class GoogleDriveConfigurationTypeDef(
     pass
 
 
+GroupMembersTypeDef = TypedDict(
+    "GroupMembersTypeDef",
+    {
+        "MemberGroups": List["MemberGroupTypeDef"],
+        "MemberUsers": List["MemberUserTypeDef"],
+        "S3PathforGroupMembers": "S3PathTypeDef",
+    },
+    total=False,
+)
+
+GroupOrderingIdSummaryTypeDef = TypedDict(
+    "GroupOrderingIdSummaryTypeDef",
+    {
+        "Status": PrincipalMappingStatusType,
+        "LastUpdatedAt": datetime,
+        "ReceivedAt": datetime,
+        "OrderingId": int,
+        "FailureReason": str,
+    },
+    total=False,
+)
+
+GroupSummaryTypeDef = TypedDict(
+    "GroupSummaryTypeDef",
+    {
+        "GroupId": str,
+        "OrderingId": int,
+    },
+    total=False,
+)
+
+HierarchicalPrincipalTypeDef = TypedDict(
+    "HierarchicalPrincipalTypeDef",
+    {
+        "PrincipalList": List["PrincipalTypeDef"],
+    },
+)
+
 _RequiredHighlightTypeDef = TypedDict(
     "_RequiredHighlightTypeDef",
     {
@@ -1021,29 +1487,142 @@ class JwtTokenTypeConfigurationTypeDef(
     pass
 
 
+_RequiredListDataSourceSyncJobsRequestRequestTypeDef = TypedDict(
+    "_RequiredListDataSourceSyncJobsRequestRequestTypeDef",
+    {
+        "Id": str,
+        "IndexId": str,
+    },
+)
+_OptionalListDataSourceSyncJobsRequestRequestTypeDef = TypedDict(
+    "_OptionalListDataSourceSyncJobsRequestRequestTypeDef",
+    {
+        "NextToken": str,
+        "MaxResults": int,
+        "StartTimeFilter": "TimeRangeTypeDef",
+        "StatusFilter": DataSourceSyncJobStatusType,
+    },
+    total=False,
+)
+
+
+class ListDataSourceSyncJobsRequestRequestTypeDef(
+    _RequiredListDataSourceSyncJobsRequestRequestTypeDef,
+    _OptionalListDataSourceSyncJobsRequestRequestTypeDef,
+):
+    pass
+
+
 ListDataSourceSyncJobsResponseTypeDef = TypedDict(
     "ListDataSourceSyncJobsResponseTypeDef",
     {
         "History": List["DataSourceSyncJobTypeDef"],
         "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredListDataSourcesRequestRequestTypeDef = TypedDict(
+    "_RequiredListDataSourcesRequestRequestTypeDef",
+    {
+        "IndexId": str,
+    },
+)
+_OptionalListDataSourcesRequestRequestTypeDef = TypedDict(
+    "_OptionalListDataSourcesRequestRequestTypeDef",
+    {
+        "NextToken": str,
+        "MaxResults": int,
     },
     total=False,
 )
 
+
+class ListDataSourcesRequestRequestTypeDef(
+    _RequiredListDataSourcesRequestRequestTypeDef, _OptionalListDataSourcesRequestRequestTypeDef
+):
+    pass
+
+
 ListDataSourcesResponseTypeDef = TypedDict(
     "ListDataSourcesResponseTypeDef",
     {
         "SummaryItems": List["DataSourceSummaryTypeDef"],
         "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredListFaqsRequestRequestTypeDef = TypedDict(
+    "_RequiredListFaqsRequestRequestTypeDef",
+    {
+        "IndexId": str,
+    },
+)
+_OptionalListFaqsRequestRequestTypeDef = TypedDict(
+    "_OptionalListFaqsRequestRequestTypeDef",
+    {
+        "NextToken": str,
+        "MaxResults": int,
     },
     total=False,
 )
 
+
+class ListFaqsRequestRequestTypeDef(
+    _RequiredListFaqsRequestRequestTypeDef, _OptionalListFaqsRequestRequestTypeDef
+):
+    pass
+
+
 ListFaqsResponseTypeDef = TypedDict(
     "ListFaqsResponseTypeDef",
     {
         "NextToken": str,
         "FaqSummaryItems": List["FaqSummaryTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredListGroupsOlderThanOrderingIdRequestRequestTypeDef = TypedDict(
+    "_RequiredListGroupsOlderThanOrderingIdRequestRequestTypeDef",
+    {
+        "IndexId": str,
+        "OrderingId": int,
+    },
+)
+_OptionalListGroupsOlderThanOrderingIdRequestRequestTypeDef = TypedDict(
+    "_OptionalListGroupsOlderThanOrderingIdRequestRequestTypeDef",
+    {
+        "DataSourceId": str,
+        "NextToken": str,
+        "MaxResults": int,
+    },
+    total=False,
+)
+
+
+class ListGroupsOlderThanOrderingIdRequestRequestTypeDef(
+    _RequiredListGroupsOlderThanOrderingIdRequestRequestTypeDef,
+    _OptionalListGroupsOlderThanOrderingIdRequestRequestTypeDef,
+):
+    pass
+
+
+ListGroupsOlderThanOrderingIdResponseTypeDef = TypedDict(
+    "ListGroupsOlderThanOrderingIdResponseTypeDef",
+    {
+        "GroupsSummaries": List["GroupSummaryTypeDef"],
+        "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+ListIndicesRequestRequestTypeDef = TypedDict(
+    "ListIndicesRequestRequestTypeDef",
+    {
+        "NextToken": str,
+        "MaxResults": int,
     },
     total=False,
 )
@@ -1053,36 +1632,114 @@ ListIndicesResponseTypeDef = TypedDict(
     {
         "IndexConfigurationSummaryItems": List["IndexConfigurationSummaryTypeDef"],
         "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredListQuerySuggestionsBlockListsRequestRequestTypeDef = TypedDict(
+    "_RequiredListQuerySuggestionsBlockListsRequestRequestTypeDef",
+    {
+        "IndexId": str,
+    },
+)
+_OptionalListQuerySuggestionsBlockListsRequestRequestTypeDef = TypedDict(
+    "_OptionalListQuerySuggestionsBlockListsRequestRequestTypeDef",
+    {
+        "NextToken": str,
+        "MaxResults": int,
     },
     total=False,
 )
 
+
+class ListQuerySuggestionsBlockListsRequestRequestTypeDef(
+    _RequiredListQuerySuggestionsBlockListsRequestRequestTypeDef,
+    _OptionalListQuerySuggestionsBlockListsRequestRequestTypeDef,
+):
+    pass
+
+
 ListQuerySuggestionsBlockListsResponseTypeDef = TypedDict(
     "ListQuerySuggestionsBlockListsResponseTypeDef",
     {
         "BlockListSummaryItems": List["QuerySuggestionsBlockListSummaryTypeDef"],
         "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+ListTagsForResourceRequestRequestTypeDef = TypedDict(
+    "ListTagsForResourceRequestRequestTypeDef",
+    {
+        "ResourceARN": str,
     },
-    total=False,
 )
 
 ListTagsForResourceResponseTypeDef = TypedDict(
     "ListTagsForResourceResponseTypeDef",
     {
         "Tags": List["TagTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredListThesauriRequestRequestTypeDef = TypedDict(
+    "_RequiredListThesauriRequestRequestTypeDef",
+    {
+        "IndexId": str,
+    },
+)
+_OptionalListThesauriRequestRequestTypeDef = TypedDict(
+    "_OptionalListThesauriRequestRequestTypeDef",
+    {
+        "NextToken": str,
+        "MaxResults": int,
     },
     total=False,
 )
 
+
+class ListThesauriRequestRequestTypeDef(
+    _RequiredListThesauriRequestRequestTypeDef, _OptionalListThesauriRequestRequestTypeDef
+):
+    pass
+
+
 ListThesauriResponseTypeDef = TypedDict(
     "ListThesauriResponseTypeDef",
     {
         "NextToken": str,
         "ThesaurusSummaryItems": List["ThesaurusSummaryTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredMemberGroupTypeDef = TypedDict(
+    "_RequiredMemberGroupTypeDef",
+    {
+        "GroupId": str,
+    },
+)
+_OptionalMemberGroupTypeDef = TypedDict(
+    "_OptionalMemberGroupTypeDef",
+    {
+        "DataSourceId": str,
     },
     total=False,
 )
 
+
+class MemberGroupTypeDef(_RequiredMemberGroupTypeDef, _OptionalMemberGroupTypeDef):
+    pass
+
+
+MemberUserTypeDef = TypedDict(
+    "MemberUserTypeDef",
+    {
+        "UserId": str,
+    },
+)
+
 _RequiredOneDriveConfigurationTypeDef = TypedDict(
     "_RequiredOneDriveConfigurationTypeDef",
     {
@@ -1118,14 +1775,26 @@ OneDriveUsersTypeDef = TypedDict(
     total=False,
 )
 
-PrincipalTypeDef = TypedDict(
-    "PrincipalTypeDef",
+_RequiredPrincipalTypeDef = TypedDict(
+    "_RequiredPrincipalTypeDef",
     {
         "Name": str,
         "Type": PrincipalTypeType,
         "Access": ReadAccessTypeType,
     },
 )
+_OptionalPrincipalTypeDef = TypedDict(
+    "_OptionalPrincipalTypeDef",
+    {
+        "DataSourceId": str,
+    },
+    total=False,
+)
+
+
+class PrincipalTypeDef(_RequiredPrincipalTypeDef, _OptionalPrincipalTypeDef):
+    pass
+
 
 _RequiredProxyConfigurationTypeDef = TypedDict(
     "_RequiredProxyConfigurationTypeDef",
@@ -1149,6 +1818,63 @@ class ProxyConfigurationTypeDef(
     pass
 
 
+_RequiredPutPrincipalMappingRequestRequestTypeDef = TypedDict(
+    "_RequiredPutPrincipalMappingRequestRequestTypeDef",
+    {
+        "IndexId": str,
+        "GroupId": str,
+        "GroupMembers": "GroupMembersTypeDef",
+    },
+)
+_OptionalPutPrincipalMappingRequestRequestTypeDef = TypedDict(
+    "_OptionalPutPrincipalMappingRequestRequestTypeDef",
+    {
+        "DataSourceId": str,
+        "OrderingId": int,
+        "RoleArn": str,
+    },
+    total=False,
+)
+
+
+class PutPrincipalMappingRequestRequestTypeDef(
+    _RequiredPutPrincipalMappingRequestRequestTypeDef,
+    _OptionalPutPrincipalMappingRequestRequestTypeDef,
+):
+    pass
+
+
+_RequiredQueryRequestRequestTypeDef = TypedDict(
+    "_RequiredQueryRequestRequestTypeDef",
+    {
+        "IndexId": str,
+        "QueryText": str,
+    },
+)
+_OptionalQueryRequestRequestTypeDef = TypedDict(
+    "_OptionalQueryRequestRequestTypeDef",
+    {
+        "AttributeFilter": "AttributeFilterTypeDef",
+        "Facets": List["FacetTypeDef"],
+        "RequestedDocumentAttributes": List[str],
+        "QueryResultTypeFilter": QueryResultTypeType,
+        "DocumentRelevanceOverrideConfigurations": List["DocumentRelevanceConfigurationTypeDef"],
+        "PageNumber": int,
+        "PageSize": int,
+        "SortingConfiguration": "SortingConfigurationTypeDef",
+        "UserContext": "UserContextTypeDef",
+        "VisitorId": str,
+    },
+    total=False,
+)
+
+
+class QueryRequestRequestTypeDef(
+    _RequiredQueryRequestRequestTypeDef, _OptionalQueryRequestRequestTypeDef
+):
+    pass
+
+
 QueryResultItemTypeDef = TypedDict(
     "QueryResultItemTypeDef",
     {
@@ -1173,8 +1899,8 @@ QueryResultTypeDef = TypedDict(
         "ResultItems": List["QueryResultItemTypeDef"],
         "FacetResults": List["FacetResultTypeDef"],
         "TotalNumberOfResults": int,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 QuerySuggestionsBlockListSummaryTypeDef = TypedDict(
@@ -1210,6 +1936,17 @@ RelevanceTypeDef = TypedDict(
     total=False,
 )
 
+ResponseMetadataTypeDef = TypedDict(
+    "ResponseMetadataTypeDef",
+    {
+        "RequestId": str,
+        "HostId": str,
+        "HTTPStatusCode": int,
+        "HTTPHeaders": Dict[str, Any],
+        "RetryAttempts": int,
+    },
+)
+
 _RequiredS3DataSourceConfigurationTypeDef = TypedDict(
     "_RequiredS3DataSourceConfigurationTypeDef",
     {
@@ -1580,12 +2317,20 @@ SqlConfigurationTypeDef = TypedDict(
     total=False,
 )
 
+StartDataSourceSyncJobRequestRequestTypeDef = TypedDict(
+    "StartDataSourceSyncJobRequestRequestTypeDef",
+    {
+        "Id": str,
+        "IndexId": str,
+    },
+)
+
 StartDataSourceSyncJobResponseTypeDef = TypedDict(
     "StartDataSourceSyncJobResponseTypeDef",
     {
         "ExecutionId": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 StatusTypeDef = TypedDict(
@@ -1599,6 +2344,37 @@ StatusTypeDef = TypedDict(
     total=False,
 )
 
+StopDataSourceSyncJobRequestRequestTypeDef = TypedDict(
+    "StopDataSourceSyncJobRequestRequestTypeDef",
+    {
+        "Id": str,
+        "IndexId": str,
+    },
+)
+
+_RequiredSubmitFeedbackRequestRequestTypeDef = TypedDict(
+    "_RequiredSubmitFeedbackRequestRequestTypeDef",
+    {
+        "IndexId": str,
+        "QueryId": str,
+    },
+)
+_OptionalSubmitFeedbackRequestRequestTypeDef = TypedDict(
+    "_OptionalSubmitFeedbackRequestRequestTypeDef",
+    {
+        "ClickFeedbackItems": List["ClickFeedbackTypeDef"],
+        "RelevanceFeedbackItems": List["RelevanceFeedbackTypeDef"],
+    },
+    total=False,
+)
+
+
+class SubmitFeedbackRequestRequestTypeDef(
+    _RequiredSubmitFeedbackRequestRequestTypeDef, _OptionalSubmitFeedbackRequestRequestTypeDef
+):
+    pass
+
+
 SuggestionHighlightTypeDef = TypedDict(
     "SuggestionHighlightTypeDef",
     {
@@ -1634,6 +2410,14 @@ SuggestionValueTypeDef = TypedDict(
     total=False,
 )
 
+TagResourceRequestRequestTypeDef = TypedDict(
+    "TagResourceRequestRequestTypeDef",
+    {
+        "ResourceARN": str,
+        "Tags": List["TagTypeDef"],
+    },
+)
+
 TagTypeDef = TypedDict(
     "TagTypeDef",
     {
@@ -1674,12 +2458,150 @@ ThesaurusSummaryTypeDef = TypedDict(
 TimeRangeTypeDef = TypedDict(
     "TimeRangeTypeDef",
     {
-        "StartTime": datetime,
-        "EndTime": datetime,
+        "StartTime": Union[datetime, str],
+        "EndTime": Union[datetime, str],
     },
     total=False,
 )
 
+UntagResourceRequestRequestTypeDef = TypedDict(
+    "UntagResourceRequestRequestTypeDef",
+    {
+        "ResourceARN": str,
+        "TagKeys": List[str],
+    },
+)
+
+_RequiredUpdateDataSourceRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateDataSourceRequestRequestTypeDef",
+    {
+        "Id": str,
+        "IndexId": str,
+    },
+)
+_OptionalUpdateDataSourceRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateDataSourceRequestRequestTypeDef",
+    {
+        "Name": str,
+        "Configuration": "DataSourceConfigurationTypeDef",
+        "Description": str,
+        "Schedule": str,
+        "RoleArn": str,
+    },
+    total=False,
+)
+
+
+class UpdateDataSourceRequestRequestTypeDef(
+    _RequiredUpdateDataSourceRequestRequestTypeDef, _OptionalUpdateDataSourceRequestRequestTypeDef
+):
+    pass
+
+
+_RequiredUpdateIndexRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateIndexRequestRequestTypeDef",
+    {
+        "Id": str,
+    },
+)
+_OptionalUpdateIndexRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateIndexRequestRequestTypeDef",
+    {
+        "Name": str,
+        "RoleArn": str,
+        "Description": str,
+        "DocumentMetadataConfigurationUpdates": List["DocumentMetadataConfigurationTypeDef"],
+        "CapacityUnits": "CapacityUnitsConfigurationTypeDef",
+        "UserTokenConfigurations": List["UserTokenConfigurationTypeDef"],
+        "UserContextPolicy": UserContextPolicyType,
+    },
+    total=False,
+)
+
+
+class UpdateIndexRequestRequestTypeDef(
+    _RequiredUpdateIndexRequestRequestTypeDef, _OptionalUpdateIndexRequestRequestTypeDef
+):
+    pass
+
+
+_RequiredUpdateQuerySuggestionsBlockListRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateQuerySuggestionsBlockListRequestRequestTypeDef",
+    {
+        "IndexId": str,
+        "Id": str,
+    },
+)
+_OptionalUpdateQuerySuggestionsBlockListRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateQuerySuggestionsBlockListRequestRequestTypeDef",
+    {
+        "Name": str,
+        "Description": str,
+        "SourceS3Path": "S3PathTypeDef",
+        "RoleArn": str,
+    },
+    total=False,
+)
+
+
+class UpdateQuerySuggestionsBlockListRequestRequestTypeDef(
+    _RequiredUpdateQuerySuggestionsBlockListRequestRequestTypeDef,
+    _OptionalUpdateQuerySuggestionsBlockListRequestRequestTypeDef,
+):
+    pass
+
+
+_RequiredUpdateQuerySuggestionsConfigRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateQuerySuggestionsConfigRequestRequestTypeDef",
+    {
+        "IndexId": str,
+    },
+)
+_OptionalUpdateQuerySuggestionsConfigRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateQuerySuggestionsConfigRequestRequestTypeDef",
+    {
+        "Mode": ModeType,
+        "QueryLogLookBackWindowInDays": int,
+        "IncludeQueriesWithoutUserInformation": bool,
+        "MinimumNumberOfQueryingUsers": int,
+        "MinimumQueryCount": int,
+    },
+    total=False,
+)
+
+
+class UpdateQuerySuggestionsConfigRequestRequestTypeDef(
+    _RequiredUpdateQuerySuggestionsConfigRequestRequestTypeDef,
+    _OptionalUpdateQuerySuggestionsConfigRequestRequestTypeDef,
+):
+    pass
+
+
+_RequiredUpdateThesaurusRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateThesaurusRequestRequestTypeDef",
+    {
+        "Id": str,
+        "IndexId": str,
+    },
+)
+_OptionalUpdateThesaurusRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateThesaurusRequestRequestTypeDef",
+    {
+        "Name": str,
+        "Description": str,
+        "RoleArn": str,
+        "SourceS3Path": "S3PathTypeDef",
+    },
+    total=False,
+)
+
+
+class UpdateThesaurusRequestRequestTypeDef(
+    _RequiredUpdateThesaurusRequestRequestTypeDef, _OptionalUpdateThesaurusRequestRequestTypeDef
+):
+    pass
+
+
 UrlsTypeDef = TypedDict(
     "UrlsTypeDef",
     {
@@ -1693,6 +2615,9 @@ UserContextTypeDef = TypedDict(
     "UserContextTypeDef",
     {
         "Token": str,
+        "UserId": str,
+        "Groups": List[str],
+        "DataSourceGroups": List["DataSourceGroupTypeDef"],
     },
     total=False,
 )
@@ -1732,3 +2657,28 @@ class WebCrawlerConfigurationTypeDef(
     _RequiredWebCrawlerConfigurationTypeDef, _OptionalWebCrawlerConfigurationTypeDef
 ):
     pass
+
+
+_RequiredWorkDocsConfigurationTypeDef = TypedDict(
+    "_RequiredWorkDocsConfigurationTypeDef",
+    {
+        "OrganizationId": str,
+    },
+)
+_OptionalWorkDocsConfigurationTypeDef = TypedDict(
+    "_OptionalWorkDocsConfigurationTypeDef",
+    {
+        "CrawlComments": bool,
+        "UseChangeLog": bool,
+        "InclusionPatterns": List[str],
+        "ExclusionPatterns": List[str],
+        "FieldMappings": List["DataSourceToIndexFieldMappingTypeDef"],
+    },
+    total=False,
+)
+
+
+class WorkDocsConfigurationTypeDef(
+    _RequiredWorkDocsConfigurationTypeDef, _OptionalWorkDocsConfigurationTypeDef
+):
+    pass
